#!/bin/sh
DIR=`dirname $0`
INSTALLDIR=`cd $DIR/../..;pwd`
VERSION=1_1

#
# Check to see if we have a jdk to install prior to running
# the tuner.
#
#if [ -d ${INSTALLDIR}/lib/jdk ]; then
#    echo "Installing new JDK..."
#    mv -f ${INSTALLDIR}/jdk ${INSTALLDIR}/jdk.old
#    rm -rf ${INSTALLDIR}/jdk.old
#    mv ${INSTALLDIR}/lib/jdk ${INSTALLDIR}/jdk
#    find ${INSTALLDIR}/jdk -name java -print | xargs chmod +x
#fi

JAVA_OS_NAME=Solaris
export JAVA_OS_NAME

PROG=${INSTALLDIR}/bin/tuner
CLASSPATH="${INSTALLDIR}/lib/tuner.zip:${INSTALLDIR}/lib/marimba.zip:${INSTALLDIR}/lib/bongo.zip:${INSTALLDIR}/etc"
export CLASSPATH

if [ -z "${JDK_HOME}" ]; then
    echo "Please set the JDK_HOME environment variable to point to"
    echo "your current JDK or JRE installation."
    exit
fi

JAVA_HOME=${JDK_HOME}

JAVA="${JAVA_HOME}/bin/java"
JAVAARGS="-noasyncgc -Dmarimba.cmd=${PROG} -Dmarimba.dir=${INSTALLDIR} -Dmarimba.root=${HOME}/.marimba"
LD_LIBRARY_PATH="${INSTALLDIR}/lib:${INSTALLDIR}/etc"
export LD_LIBRARY_PATH

#
# Check to see if this has been fully installed.  If it hasn't, check
# to see if we have permission to do it ourselves.
#
if [ \! -f ${INSTALLDIR}/lib/bongo.zip ]; then
    if [ -w ${INSTALLDIR}/lib ]; then
	# We are ashamed of this, so we are not going to comment it
	# This is to avoid overwriting open files
	for i in libmarimba.so tuner.zip marimba.zip bongo.zip; do
	    rm -f ${INSTALLDIR}/lib/$i
	    ln ${INSTALLDIR}/lib/X$i ${INSTALLDIR}/lib/$i
	done
    else
	echo "This tuner has not been fully installed.  It must be"
	echo "run once by a user with permission to write into the"
	echo "${INSTALLDIR}/lib directory."
	exit 1
    fi
fi

CHECK=false
if [ ! -r ${HOME}/.marimba/tuner.version ]; then
    CHECK=true
else
    if [ x`cat ${HOME}/.marimba/tuner.version` != x"${VERSION}" ]; then
	CHECK=true
    fi
fi
if [ "$CHECK" = true ]; then
	if ${JAVA} ${JAVAARGS} marimba.desktop.LicenseDialog ${INSTALLDIR}/LICENSE.txt; then
		exit 1
	fi
	mkdir -p ${HOME}/.marimba 2>/dev/null
	echo ${VERSION} > ${HOME}/.marimba/tuner.version
fi

${JAVA} ${JAVAARGS} marimba.apps.tuner.Main $*
result="$?"
while true; do
    if [ "$result" -eq "2" ] ; then
        # We are ashamed of this, so we are not going to comment it
        # This is to avoid overwriting open files
        for i in libmarimba.so tuner.zip marimba.zip bongo.zip; do
            rm -f ${INSTALLDIR}/lib/$i
            ln ${INSTALLDIR}/lib/X$i ${INSTALLDIR}/lib/$i
        done
        ${JAVA} ${JAVAARGS} marimba.apps.tuner.Main
	result=$?
    elif [ "$result" -eq "3" ] ; then
	if [ -d ${INSTALLDIR}/lib/channel.dir ]; then
	    mv ${INSTALLDIR}/lib/channel.dir ${INSTALLDIR}/lib/.castanet
	fi
        ${JAVA} ${JAVAARGS} marimba.apps.tuner.Main -update
	result=$?
    else
	exit $result
    fi
done
